@@ -178,6 +178,9 @@ class ApiClient(object):
 
         return result.value
 
+    def callstats(self):
+        return (self._calls_time, self._calls)
+
 
 class Service(object):
     """
